﻿using System.Collections.ObjectModel;
using System.ComponentModel;

//REMEMBER: namespace
namespace SLSPConf
{
    /// <summary>
    /// Two interfaces for easy databinding in Silverlight:
    /// 
    /// INotifyPropertyChanged - for entity - raise event when a property is updated and tells the UI
    /// ObservableCollection - for collections - raises event(s) when elements add/removed, provides enumerator
    /// 
    /// </summary>
    public class PollItem : INotifyPropertyChanged
    {
        private string surveyChoice = "";
        private int surveyCount = 0;

        public PollItem(string Choice, int Count)
        {
            surveyChoice = Choice;
            surveyCount = Count;
        }

        /// <summary>
        /// A Choice in this survey
        /// </summary>
        public string SurveyChoice
        {
            get
            {
                return surveyChoice;
            }
            set
            {
                surveyChoice = value;
                OnPropertyChanged("SurveyChoice");
            }
        }

        /// <summary>
        /// Number of votes for this choice
        /// </summary>
        public int SurveyCount
        {
            get
            {
                return surveyCount;
            }
            set
            {
                surveyCount = value;
                OnPropertyChanged("SurveyCount");
            }
        }

        #region Implement INotifyPropertyChanged interface

        public event PropertyChangedEventHandler PropertyChanged;

        void OnPropertyChanged(string propertyName)
        {
            // check event handlers exists
            if (PropertyChanged != null)
            {
                // raise event
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion
    }

    public class PollCollection : ObservableCollection<PollItem>
    {
        // just a strongly typed observable collection
    }
}
