﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.SharePoint.Client;
using System.Windows.Threading;

namespace SLSPConf
{
    public partial class SharePointChart : UserControl
    {
        ClientContext sharepointContext;

        public SharePointChart()
        {
            InitializeComponent();
            sharepointContext = ClientContext.Current;

            if (sharepointContext == null)
            {
                sharepointContext = new ClientContext("http://colt-sp2010/sites/Home/");
            }

            DispatcherTimer timer = new DispatcherTimer();
            timer.Interval = new TimeSpan(0, 0, 5);
            timer.Tick += new EventHandler(timer_Tick);
            timer.Start();
        }

        private void timer_Tick(object sender, EventArgs e)
        {
            if (sharepointContext == null)
            {
                GetData();
            }
            else
            {
                QueryDataFromSharePoint();
            }
        }

        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {
            if (sharepointContext == null)
            {
                GetData();
            }
            else
            {
                QueryDataFromSharePoint();
            }
        }

        private const string ListName = "Football";
        private const string InternalFieldName = "FavouriteCountry";
        private ListItemCollection listItems;
        private IEnumerable<ListItem> listItems2;

        private void QueryDataFromSharePoint()
        {
            Web web = sharepointContext.Web;
            // get our list
            List list = web.Lists.GetByTitle(ListName);
            // get items in our list
            listItems = list.GetItems(CamlQuery.CreateAllItemsQuery());

            // still need the earlier syntax to tell sharepoint where to get it
            listItems2 = sharepointContext.LoadQuery(
                listItems.Include(
                    item => item["Title"],
                    item => item[InternalFieldName])
                //.Where(
                //    item => (string)item["Title"] == "sanjay")

                );

            // but don't actually load it!

            // tell context we want to load them
            //sharepointContext.Load(list);
            //sharepointContext.Load(listItems);

            // execute the load asynchronously
            sharepointContext.ExecuteQueryAsync(SucceededCallback, FailedCallback);
        }

        private void FailedCallback(object sender, ClientRequestFailedEventArgs e)
        {
            throw new NotImplementedException();
        }

        private void SucceededCallback(object sender, ClientRequestSucceededEventArgs e)
        {
            this.Dispatcher.BeginInvoke(UpdateDataFromSharePoint);
        }

        private void UpdateDataFromSharePoint()
        {
            // loop through the list from sharepoint - update my dictionary with count
            Dictionary<string, int> summary = new Dictionary<string, int>();
            foreach (var listitem in listItems2)
            {
                string country = listitem[InternalFieldName].ToString();
                if (!summary.ContainsKey(country))
                {
                    summary[country] = 1;
                }
                else
                {
                    summary[country]++;
                }
            }


            PollCollection collection = this.Resources["Collection"] as PollCollection;

            // loop through collection - update any count
            foreach (var item in collection)
            {
                if (summary.ContainsKey(item.SurveyChoice))
                {
                    item.SurveyCount = summary[item.SurveyChoice];
                    summary.Remove(item.SurveyChoice);
                }
                else
                {
                    item.SurveyCount = 0;
                }
            }

            // add any new entries
            foreach (var item in summary)
            {
                collection.Add(new PollItem(item.Key, item.Value));
            }
        }

        private void GetData()
        {
            UpdateCollection();
        }

        private void UpdateCollection()
        {
            PollCollection collection = this.Resources["Collection"] as PollCollection;

            collection.Add(new PollItem("Australia", 10));
            collection.Add(new PollItem("NZ", 1));
            collection.Add(new PollItem("Germany", 1));
        }
    }
}
